<?php
/**
 * playne functions and definitions
 *
 * @package playne
 */

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function playne_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'playne_content_width', 640 );
}
add_action( 'after_setup_theme', 'playne_content_width', 0 );


/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function playne_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on playne, use a find and replace
	 * to change 'playne' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'playne', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'playne' ),
	) );
add_action( 'init', 'playne_nav_menus' );

function playne_nav_menus() {
	register_nav_menu( 'social', __( 'Social', 'playne' ) );
}
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'playne_custom_background_args', array(
		'default-color' => 'eeeeee',
		'default-image' => get_template_directory_uri() . '/images/diagonal-noise.png',
	) ) );
}
add_action( 'after_setup_theme', 'playne_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function playne_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'playne' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Sidebar 1', 'playne' ),
		'id' => 'footer-sidebar-1',
		'description' => __( 'Appears in the footer area', 'playne' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
) );

	register_sidebar( array(
		'name' => __( 'Footer Sidebar 2', 'playne' ),
		'id' => 'footer-sidebar-2',
		'description' => __( 'Appears in the footer area', 'playne' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
) );

	register_sidebar( array(
		'name' => __( 'Footer Sidebar 3', 'playne' ),
		'id' => 'footer-sidebar-3',
		'description' => __( 'Appears in the footer area', 'playne' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
) );

	register_sidebar( array(
		'name' => __( 'Footer Sidebar 4', 'playne' ),
		'id' => 'footer-sidebar-4',
		'description' => __( 'Appears in the footer area', 'playne' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
) );


	register_sidebar( array(
		'name' => __( 'Footer Disclaimer', 'playne' ),
		'id' => 'footer-disclaimer',
		'description' => __( 'Appears in the footer area above the bottome line. Stretching across the bottom, it is intended for copyright, terms, etc. Use text widget only-no title.', 'playne' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '',
		'after_title' => '',
) );
}



add_action( 'widgets_init', 'playne_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function playne_scripts() {
	wp_enqueue_style( 'playne-style', get_stylesheet_uri() );

	wp_enqueue_style( 'playne-style-content-sidebar', get_template_directory_uri() . '/layouts/content-sidebar.css');

	wp_enqueue_style ('font-awesome', get_template_directory_uri() . '/font-awesome.css');
    
    wp_enqueue_script( 'playne-js', get_template_directory_uri() . '/js/playne.js', array('jquery'), '1.0.0', true );

	wp_enqueue_script( 'playne-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'playne_scripts' );

/**
 * Registers an editor stylesheet for the theme.
 */
function add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'add_editor_styles' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

function playne_custom_logo_setup() {
    $defaults = array(
        'height'      => 30,
        'width'       => 30,
        'flex-width'  => true,
    );
add_theme_support( 'custom-logo', $defaults );
}
add_action( 'after_setup_theme', 'playne_custom_logo_setup' );

add_theme_support ( 'custom-logo' );


/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @global WP_Query   $wp_query   WordPress Query object.
 * @global WP_Rewrite $wp_rewrite WordPress Rewrite object.
 */
